"""
$RCSfile: SandboxInfo.py,v $

SandboxInfo encapsulates information about CVS sandboxes.

Author: <a href="mailto:cstrong@arielpartners.com">Craeg Strong</a>
Release: 1.0
"""

__cvstag__  = '$Name:  $'[6:-2]
__date__    = '$Date: 2002/08/27 23:39:05 $'[6:-2]
__version__ = '$Revision: 1.3 $'[10:-2]

# Zope builtins
from AccessControl import ClassSecurityInfo
import Globals  # InitializeClass (security stuff)

class SandboxInfo(ClassSecurityInfo):

    _security = ClassSecurityInfo()

    # Set security for the object itself, e.g. if it is accessed in DTML code
    # This line is REQUIRED to allow access to SandboxInfo by the public
    _security.declareObjectPublic()

    def __init__(self, name='', basedir='', cvsroot=''):
        self.name    = name
        self.basedir = basedir
        self.cvsroot = cvsroot

    # Allow access from DTML scripts through the web
    _security.declarePublic('getname')
    def getname(self):
        return self.name

    # Allow access from DTML scripts through the web
    _security.declarePublic('getbasedir')
    def getbasedir(self):
        return self.basedir

    # Allow access from DTML scripts through the web
    _security.declarePublic('getcvsroot')
    def getcvsroot(self):
        return self.cvsroot

    def __str__(self):
        return "sandbox name: " +  self.name +  " basedir: " + \
               self.basedir + " cvsroot: " + self.cvsroot

    _security.declarePublic('__eq__')
    def __eq__(self, other):
        """

        Return true if self equals the other.  Two SIs are equal if
        they have equal (not necessarily identical) values for the
        following attributes:

          - name
          - basedir
          - cvsroot

        """
        true = 1
        false = 0
        if self is other: return true

        # Must use __class__, not type, because type may pick
        # up acquisition wrapper on one but not the other
        if getattr(other, '__class__', None) is None:
            return false
        if other.__class__ != self.__class__: return false
        if self.name != other.name: return false
        if self.basedir != other.basedir: return false
        if self.cvsroot != other.cvsroot: return false

        return true
        
    def __ne__(self, other):
        return not self.__eq__(other)

    def __cmp__(self, other):
        # raise NotImplementedError('SandboxInfo does not implement __cmp__')
        # Note: Because we are defining rich comparisons, this function
        # should never be called by ==. However, it seems to be.
        # Tasks are not intrinsically ordered, so < and > make no sense.
        # For now, just punt. Is this a Python 2.1.x bug?? WGM 8/18/02.
        if self.__eq__(other): return 0
        else: return 1
    
    def __lt__(self, other):
        raise NotImplementedError('SandboxInfo does not implement __lt__')

    def __le__(self, other):
        raise NotImplementedError('SandboxInfo does not implement __le__')

    def __gt__(self, other):
        raise NotImplementedError('SandboxInfo does not implement __gt__')

    def __ge__(self, other):
        raise NotImplementedError('SandboxInfo does not implement __ge__')

# register security information
Globals.InitializeClass(SandboxInfo)
